package com.muyu.businessPlatform.controller;

import com.muyu.businessPlatform.domain.Fence;
import com.muyu.businessPlatform.service.IFenceService;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 电子围栏Controller
 *
 * @author wan
 * @date 2024-05-31
 */
@RestController
@RequestMapping("/fence")
public class FenceController extends BaseController
{
    @Autowired
    private IFenceService fenceService;

    /**
     * 查询电子围栏列表
     */
    @RequiresPermissions("businessPlatform:fence:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Fence>> list(Fence fence)
    {
        startPage();
        List<Fence> list = fenceService.selectFenceList(fence);
        return getDataTable(list);
    }

    /**
     * 导出电子围栏列表
     */
    @RequiresPermissions("businessPlatform:fence:export")
    @Log(title = "电子围栏", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Fence fence)
    {
        List<Fence> list = fenceService.selectFenceList(fence);
        ExcelUtil<Fence> util = new ExcelUtil<Fence>(Fence.class);
        util.exportExcel(response, list, "电子围栏数据");
    }

    /**
     * 获取电子围栏详细信息
     */
    @RequiresPermissions("businessPlatform:fence:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(fenceService.selectFenceById(id));
    }

    /**
     * 新增电子围栏
     */
    @RequiresPermissions("businessPlatform:fence:add")
    @Log(title = "电子围栏", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody Fence fence)
    {
        return toAjax(fenceService.insertFence(fence));
    }

    /**
     * 修改电子围栏
     */
    @RequiresPermissions("businessPlatform:fence:edit")
    @Log(title = "电子围栏", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody Fence fence)
    {
        return toAjax(fenceService.updateFence(fence));
    }

    /**
     * 删除电子围栏
     */
    @RequiresPermissions("businessPlatform:fence:remove")
    @Log(title = "电子围栏", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(fenceService.deleteFenceByIds(ids));
    }
}
