package com.muyu.authentication.controller;

import com.muyu.authentication.service.ICertificationService;
import com.muyu.domain.Certification;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 企业认证Controller
 *
 * @author wan
 * @date 2024-05-31
 */
@RestController
@RequestMapping("/certification")
public class CertificationController extends BaseController
{
    @Autowired
    private ICertificationService certificationService;

    /**
     * 查询企业认证列表
     */
    @RequiresPermissions("authentication:certification:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Certification>> list(Certification certification)
    {
        startPage();
        List<Certification> list = certificationService.selectCertificationList(certification);
        return getDataTable(list);
    }

    /**
     * 导出企业认证列表
     */
    @RequiresPermissions("authentication:certification:export")
    @Log(title = "企业认证", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Certification certification)
    {
        List<Certification> list = certificationService.selectCertificationList(certification);
        ExcelUtil<Certification> util = new ExcelUtil<Certification>(Certification.class);
        util.exportExcel(response, list, "企业认证数据");
    }

    /**
     * 获取企业认证详细信息
     */
    @RequiresPermissions("authentication:certification:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(certificationService.selectCertificationById(id));
    }

    /**
     * 新增企业认证
     */
    @RequiresPermissions("authentication:certification:add")
    @Log(title = "企业认证", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody Certification certification)
    {
        return toAjax(certificationService.insertCertification(certification));
    }

    /**
     * 修改企业认证
     */
    @RequiresPermissions("authentication:certification:edit")
    @Log(title = "企业认证", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody Certification certification)
    {
        return toAjax(certificationService.updateCertification(certification));
    }

    /**
     * 删除企业认证
     */
    @RequiresPermissions("authentication:certification:remove")
    @Log(title = "企业认证", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(certificationService.deleteCertificationByIds(ids));
    }
}
