package com.muyu.authentication.controller;

import com.muyu.authentication.service.IOpenServiceService;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.domain.OpenService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 开通类型Controller
 *
 * @author wan
 * @date 2024-05-31
 */
@RestController
@RequestMapping("/openService")
public class OpenServiceController extends BaseController
{
    @Autowired
    private IOpenServiceService openServiceService;

    /**
     * 查询开通类型列表
     */
    @RequiresPermissions("authentication:openService:list")
    @GetMapping("/list")
    public Result<TableDataInfo<OpenService>> list(OpenService openService)
    {
        startPage();
        List<OpenService> list = openServiceService.selectOpenServiceList(openService);
        return getDataTable(list);
    }

    /**
     * 导出开通类型列表
     */
    @RequiresPermissions("authentication:openService:export")
    @Log(title = "开通类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, OpenService openService)
    {
        List<OpenService> list = openServiceService.selectOpenServiceList(openService);
        ExcelUtil<OpenService> util = new ExcelUtil<OpenService>(OpenService.class);
        util.exportExcel(response, list, "开通类型数据");
    }

    /**
     * 获取开通类型详细信息
     */
    @RequiresPermissions("authentication:openService:query")
    @GetMapping(value = "/{id}")
    public Result<OpenService> getInfo(@PathVariable("id") Long id)
    {
        return Result.success(openServiceService.selectOpenServiceById(id));
    }

    /**
     * 新增开通类型
     */
    @RequiresPermissions("authentication:openService:add")
    @Log(title = "开通类型", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody OpenService openService)
    {
        return toAjax(openServiceService.insertOpenService(openService));
    }

    /**
     * 修改开通类型
     */
    @RequiresPermissions("authentication:openService:edit")
    @Log(title = "开通类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody OpenService openService)
    {
        return toAjax(openServiceService.updateOpenService(openService));
    }

    /**
     * 删除开通类型
     */
    @RequiresPermissions("authentication:openService:remove")
    @Log(title = "开通类型", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(openServiceService.deleteOpenServiceByIds(ids));
    }
}
