package com.muyu.authentication.service.impl;

import com.muyu.authentication.mapper.CertificationMapper;
import com.muyu.authentication.service.ICertificationService;
import com.muyu.common.core.utils.DateUtils;
import com.muyu.domain.Certification;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 企业认证Service业务层处理
 *
 * @author wan
 * @date 2024-05-31
 */
@Service
public class CertificationServiceImpl implements ICertificationService
{
    @Autowired
    private CertificationMapper certificationMapper;

    /**
     * 查询企业认证
     *
     * @param id 企业认证主键
     * @return 企业认证
     */
    @Override
    public Certification selectCertificationById(Long id)
    {
        return certificationMapper.selectCertificationById(id);
    }

    /**
     * 查询企业认证列表
     *
     * @param certification 企业认证
     * @return 企业认证
     */
    @Override
    public List<Certification> selectCertificationList(Certification certification)
    {
        return certificationMapper.selectCertificationList(certification);
    }

    /**
     * 新增企业认证
     *
     * @param certification 企业认证
     * @return 结果
     */
    @Override
    public int insertCertification(Certification certification)
    {
        certification.setCreateTime(DateUtils.getNowDate());
        return certificationMapper.insertCertification(certification);
    }

    /**
     * 修改企业认证
     *
     * @param certification 企业认证
     * @return 结果
     */
    @Override
    public int updateCertification(Certification certification)
    {
        certification.setUpdateTime(DateUtils.getNowDate());
        return certificationMapper.updateCertification(certification);
    }

    /**
     * 批量删除企业认证
     *
     * @param ids 需要删除的企业认证主键
     * @return 结果
     */
    @Override
    public int deleteCertificationByIds(Long[] ids)
    {
        return certificationMapper.deleteCertificationByIds(ids);
    }

    /**
     * 删除企业认证信息
     *
     * @param id 企业认证主键
     * @return 结果
     */
    @Override
    public int deleteCertificationById(Long id)
    {
        return certificationMapper.deleteCertificationById(id);
    }
}
