package com.muyu.authentication.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.authentication.mapper.EnterpriseMapper;
import com.muyu.common.core.utils.DateUtils;
import com.muyu.common.system.domain.SysUser;
import com.muyu.common.system.remote.RemoteUserService;
import com.muyu.system.mapper.SysUserMapper;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.muyu.domain.Enterprise;
import com.muyu.authentication.service.IEnterpriseService;

/**
 * 企业Service业务层处理
 *
 * @author wan
 * @date 2024-05-31
 */
@Service
@Log4j2
public class EnterpriseServiceImpl extends ServiceImpl<EnterpriseMapper,Enterprise> implements IEnterpriseService
{
    @Autowired
    private EnterpriseMapper enterpriseMapper;

    /**
     * 查询企业
     *
     * @param id 企业主键
     * @return 企业
     */
    @Override
    public Enterprise selectEnterpriseById(Long id)
    {
        return enterpriseMapper.selectOne(
                new LambdaQueryWrapper<>(){{
                    eq(Enterprise::getId,id);
                }}
        );
    }

    /**
     * 查询企业列表
     *
     * @param enterprise 企业
     * @return 企业
     */
    @Override
    public List<Enterprise> selectEnterpriseList(Enterprise enterprise)
    {
        return enterpriseMapper.selectEnterpriseList(enterprise);
    }

    @Autowired
    private RemoteUserService remoteUserService;
    /**
     * 新增企业
     *
     * @param enterprise 企业
     * @return 结果
     */
    @Override
    public int insertEnterprise(Enterprise enterprise)
    {
        enterprise.setCreateTime(DateUtils.getNowDate());
        int insert = enterpriseMapper.insert(enterprise);
        if (insert>0) {
            SysUser build = SysUser.builder()
                    .userName(enterprise.getEnterpriseName())
                    .nickName(enterprise.getLegalPerson())
                    .email(enterprise.getEmail())
                    .phonenumber(enterprise.getContactPhone())
                    .password(enterprise.getContactPhone().substring(enterprise.getContactPhone().length()-6))
                    .companyId(enterprise.getId())
                    .status("0")
                    .roleId(9L)
                    .build();
            log.info(build.getPassword());
            remoteUserService.add(build);
        }
        return insert;
    }

    /**
     * 修改企业
     *
     * @param enterprise 企业
     * @return 结果
     */
    @Override
    public int updateEnterprise(Enterprise enterprise)
    {
        enterprise.setUpdateTime(DateUtils.getNowDate());
        return enterpriseMapper.updateById(enterprise);
    }

    /**
     * 批量删除企业
     *
     * @param ids 需要删除的企业主键
     * @return 结果
     */
    @Override
    public int deleteEnterpriseByIds(Long[] ids)
    {
        return enterpriseMapper.deleteEnterpriseByIds(ids);
    }

    /**
     * 删除企业信息
     *
     * @param id 企业主键
     * @return 结果
     */
    @Override
    public int deleteEnterpriseById(Long id)
    {
        return enterpriseMapper.deleteById(id);
    }
}
