package com.muyu.authentication.service.impl;

import com.muyu.authentication.mapper.OpenServiceMapper;
import com.muyu.authentication.service.IOpenServiceService;
import com.muyu.common.core.utils.DateUtils;
import com.muyu.domain.OpenService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 开通类型Service业务层处理
 *
 * @author wan
 * @date 2024-05-31
 */
@Service
public class OpenServiceServiceImpl implements IOpenServiceService
{
    @Autowired
    private OpenServiceMapper openServiceMapper;

    /**
     * 查询开通类型
     *
     * @param id 开通类型主键
     * @return 开通类型
     */
    @Override
    public OpenService selectOpenServiceById(Long id)
    {
        return openServiceMapper.selectOpenServiceById(id);
    }

    /**
     * 查询开通类型列表
     *
     * @param openService 开通类型
     * @return 开通类型
     */
    @Override
    public List<OpenService> selectOpenServiceList(OpenService openService)
    {
        return openServiceMapper.selectOpenServiceList(openService);
    }

    /**
     * 新增开通类型
     *
     * @param openService 开通类型
     * @return 结果
     */
    @Override
    public int insertOpenService(OpenService openService)
    {
        openService.setCreateTime(DateUtils.getNowDate());
        return openServiceMapper.insertOpenService(openService);
    }

    /**
     * 修改开通类型
     *
     * @param openService 开通类型
     * @return 结果
     */
    @Override
    public int updateOpenService(OpenService openService)
    {
        openService.setUpdateTime(DateUtils.getNowDate());
        return openServiceMapper.updateOpenService(openService);
    }

    /**
     * 批量删除开通类型
     *
     * @param ids 需要删除的开通类型主键
     * @return 结果
     */
    @Override
    public int deleteOpenServiceByIds(Long[] ids)
    {
        return openServiceMapper.deleteOpenServiceByIds(ids);
    }

    /**
     * 删除开通类型信息
     *
     * @param id 开通类型主键
     * @return 结果
     */
    @Override
    public int deleteOpenServiceById(Long id)
    {
        return openServiceMapper.deleteOpenServiceById(id);
    }
}
