package com.muyu.authentication.service.impl;

import com.muyu.authentication.mapper.PayForMapper;
import com.muyu.authentication.service.IPayForService;
import com.muyu.common.core.utils.DateUtils;
import com.muyu.domain.PayFor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 支付Service业务层处理
 *
 * @author wan
 * @date 2024-05-31
 */
@Service
public class PayForServiceImpl implements IPayForService
{
    @Autowired
    private PayForMapper payForMapper;

    /**
     * 查询支付
     *
     * @param id 支付主键
     * @return 支付
     */
    @Override
    public PayFor selectPayForById(Long id)
    {
        return payForMapper.selectPayForById(id);
    }

    /**
     * 查询支付列表
     *
     * @param payFor 支付
     * @return 支付
     */
    @Override
    public List<PayFor> selectPayForList(PayFor payFor)
    {
        return payForMapper.selectPayForList(payFor);
    }

    /**
     * 新增支付
     *
     * @param payFor 支付
     * @return 结果
     */
    @Override
    public int insertPayFor(PayFor payFor)
    {
        payFor.setCreateTime(DateUtils.getNowDate());
        return payForMapper.insertPayFor(payFor);
    }

    /**
     * 修改支付
     *
     * @param payFor 支付
     * @return 结果
     */
    @Override
    public int updatePayFor(PayFor payFor)
    {
        payFor.setUpdateTime(DateUtils.getNowDate());
        return payForMapper.updatePayFor(payFor);
    }

    /**
     * 批量删除支付
     *
     * @param ids 需要删除的支付主键
     * @return 结果
     */
    @Override
    public int deletePayForByIds(Long[] ids)
    {
        return payForMapper.deletePayForByIds(ids);
    }

    /**
     * 删除支付信息
     *
     * @param id 支付主键
     * @return 结果
     */
    @Override
    public int deletePayForById(Long id)
    {
        return payForMapper.deletePayForById(id);
    }
}
